# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/wallet/account/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/wallet/account/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as meshtrade_dot_option_dot_method__options_dot_v1_dot_method__options__pb2
from meshtrade.type.v1 import sorting_pb2 as meshtrade_dot_type_dot_v1_dot_sorting__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2
from meshtrade.wallet.account.v1 import account_pb2 as meshtrade_dot_wallet_dot_account_dot_v1_dot_account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)meshtrade/wallet/account/v1/service.proto\x12\x1bmeshtrade.wallet.account.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x37meshtrade/option/method_options/v1/method_options.proto\x1a\x1fmeshtrade/type/v1/sorting.proto\x1a\x1dmeshtrade/type/v1/token.proto\x1a)meshtrade/wallet/account/v1/account.proto\"^\n\x14\x43reateAccountRequest\x12\x46\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32$.meshtrade.wallet.account.v1.AccountB\x06\xbaH\x03\xc8\x01\x01R\x07\x61\x63\x63ount\"^\n\x14UpdateAccountRequest\x12\x46\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32$.meshtrade.wallet.account.v1.AccountB\x06\xbaH\x03\xc8\x01\x01R\x07\x61\x63\x63ount\"e\n\x12OpenAccountRequest\x12O\n\x04name\x18\x01 \x01(\tB;\xbaH8r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01#R\x04name\"D\n\x13OpenAccountResponse\x12-\n\x12ledger_transaction\x18\x01 \x01(\tR\x11ledgerTransaction\"\xa5\x03\n\x1e\x41\x64\x64SignatoriesToAccountRequest\x12O\n\x04name\x18\x01 \x01(\tB;\xbaH8r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01#R\x04name\x12\xb1\x02\n\x05users\x18\x02 \x03(\tB\x9a\x02\xbaH\x96\x02\x92\x01\x92\x02\x08\x01\x10\x64\"\x8b\x02r<2:^(users|api_users)/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\xba\x01\xc9\x01\n\x0cusers.format\x12\x32\x65\x61\x63h user must be api_users/{ULID} or users/{ULID}\x1a\x84\x01this.matches(\'^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\') || this.matches(\'^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')R\x05users\"P\n\x1f\x41\x64\x64SignatoriesToAccountResponse\x12-\n\x12ledger_transaction\x18\x01 \x01(\tR\x11ledgerTransaction\"\xaa\x03\n#RemoveSignatoriesFromAccountRequest\x12O\n\x04name\x18\x01 \x01(\tB;\xbaH8r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01#R\x04name\x12\xb1\x02\n\x05users\x18\x02 \x03(\tB\x9a\x02\xbaH\x96\x02\x92\x01\x92\x02\x08\x01\x10\x64\"\x8b\x02r<2:^(users|api_users)/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\xba\x01\xc9\x01\n\x0cusers.format\x12\x32\x65\x61\x63h user must be api_users/{ULID} or users/{ULID}\x1a\x84\x01this.matches(\'^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\') || this.matches(\'^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')R\x05users\"U\n$RemoveSignatoriesFromAccountResponse\x12-\n\x12ledger_transaction\x18\x01 \x01(\tR\x11ledgerTransaction\"\x96\x01\n\x11GetAccountRequest\x12O\n\x04name\x18\x01 \x01(\tB;\xbaH8r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01#R\x04name\x12\x30\n\x14populate_ledger_data\x18\x02 \x01(\x08R\x12populateLedgerData\"\x88\x01\n\x19GetAccountByNumberRequest\x12\x39\n\x0e\x61\x63\x63ount_number\x18\x01 \x01(\tB\x12\xbaH\x0fr\r2\x0b^1[0-9]{6}$R\raccountNumber\x12\x30\n\x14populate_ledger_data\x18\x02 \x01(\x08R\x12populateLedgerData\"\xd5\x02\n\x13ListAccountsRequest\x12R\n\x07sorting\x18\x01 \x01(\x0b\x32\x38.meshtrade.wallet.account.v1.ListAccountsRequest.SortingR\x07sorting\x12\x30\n\x14populate_ledger_data\x18\x02 \x01(\x08R\x12populateLedgerData\x1a\xb7\x01\n\x07Sorting\x12u\n\x05\x66ield\x18\x01 \x01(\tB_\xbaH\\r\nR\x00R\x06number\xba\x01M\n\x0b\x66ield.valid\x12&field must be one of: number, or empty\x1a\x16this in [\'\', \'number\']R\x05\x66ield\x12\x35\n\x05order\x18\x02 \x01(\x0e\x32\x1f.meshtrade.type.v1.SortingOrderR\x05order\"X\n\x14ListAccountsResponse\x12@\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32$.meshtrade.wallet.account.v1.AccountR\x08\x61\x63\x63ounts\"\xef\x03\n\x15SearchAccountsRequest\x12T\n\x07sorting\x18\x01 \x01(\x0b\x32:.meshtrade.wallet.account.v1.SearchAccountsRequest.SortingR\x07sorting\x12\x93\x01\n\x0c\x64isplay_name\x18\x02 \x01(\tBp\xbaHmr\x03\x18\xff\x01\xba\x01\x65\n\x17\x64isplay_name.max_length\x12\x37\x64isplay_name search term must not exceed 255 characters\x1a\x11size(this) <= 255R\x0b\x64isplayName\x12\x30\n\x14populate_ledger_data\x18\x03 \x01(\x08R\x12populateLedgerData\x1a\xb7\x01\n\x07Sorting\x12u\n\x05\x66ield\x18\x01 \x01(\tB_\xbaH\\r\nR\x00R\x06number\xba\x01M\n\x0b\x66ield.valid\x12&field must be one of: number, or empty\x1a\x16this in [\'\', \'number\']R\x05\x66ield\x12\x35\n\x05order\x18\x02 \x01(\x0e\x32\x1f.meshtrade.type.v1.SortingOrderR\x05order\"Z\n\x16SearchAccountsResponse\x12@\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32$.meshtrade.wallet.account.v1.AccountR\x08\x61\x63\x63ounts\"\xaf\x01\n\x1eRegisterTokensToAccountRequest\x12O\n\x04name\x18\x01 \x01(\tB;\xbaH8r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01#R\x04name\x12<\n\x06tokens\x18\x02 \x03(\x0b\x32\x18.meshtrade.type.v1.TokenB\n\xbaH\x07\x92\x01\x04\x08\x01\x10\nR\x06tokens\"P\n\x1fRegisterTokensToAccountResponse\x12-\n\x12ledger_transaction\x18\x01 \x01(\tR\x11ledgerTransaction\"\xb3\x01\n\"DeregisterTokensFromAccountRequest\x12O\n\x04name\x18\x01 \x01(\tB;\xbaH8r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01#R\x04name\x12<\n\x06tokens\x18\x02 \x03(\x0b\x32\x18.meshtrade.type.v1.TokenB\n\xbaH\x07\x92\x01\x04\x08\x01\x10\nR\x06tokens\"T\n#DeregisterTokensFromAccountResponse\x12-\n\x12ledger_transaction\x18\x01 \x01(\tR\x11ledgerTransaction2\xf7\x0c\n\x0e\x41\x63\x63ountService\x12z\n\rCreateAccount\x12\x31.meshtrade.wallet.account.v1.CreateAccountRequest\x1a$.meshtrade.wallet.account.v1.Account\"\x10\xb2\xb5\x18\x0c\x08\x02\x10\x02\x1a\x06\xc0\x84=\xc2\x84=\x12z\n\rUpdateAccount\x12\x31.meshtrade.wallet.account.v1.UpdateAccountRequest\x1a$.meshtrade.wallet.account.v1.Account\"\x10\xb2\xb5\x18\x0c\x08\x02\x10\x02\x1a\x06\xc0\x84=\xc2\x84=\x12\x82\x01\n\x0bOpenAccount\x12/.meshtrade.wallet.account.v1.OpenAccountRequest\x1a\x30.meshtrade.wallet.account.v1.OpenAccountResponse\"\x10\xb2\xb5\x18\x0c\x08\x02\x10\x02\x1a\x06\xc0\x84=\xc2\x84=\x12\xa6\x01\n\x17\x41\x64\x64SignatoriesToAccount\x12;.meshtrade.wallet.account.v1.AddSignatoriesToAccountRequest\x1a<.meshtrade.wallet.account.v1.AddSignatoriesToAccountResponse\"\x10\xb2\xb5\x18\x0c\x08\x02\x10\x02\x1a\x06\xc0\x84=\xc2\x84=\x12\xb5\x01\n\x1cRemoveSignatoriesFromAccount\x12@.meshtrade.wallet.account.v1.RemoveSignatoriesFromAccountRequest\x1a\x41.meshtrade.wallet.account.v1.RemoveSignatoriesFromAccountResponse\"\x10\xb2\xb5\x18\x0c\x08\x02\x10\x02\x1a\x06\xc0\x84=\xc2\x84=\x12z\n\nGetAccount\x12..meshtrade.wallet.account.v1.GetAccountRequest\x1a$.meshtrade.wallet.account.v1.Account\"\x16\xb2\xb5\x18\x12\x08\x01\x10\x02\x1a\x0c\xc0\x84=\xc1\x84=\xc2\x84=\xc3\x84=\x12\x8a\x01\n\x12GetAccountByNumber\x12\x36.meshtrade.wallet.account.v1.GetAccountByNumberRequest\x1a$.meshtrade.wallet.account.v1.Account\"\x16\xb2\xb5\x18\x12\x08\x01\x10\x02\x1a\x0c\xc0\x84=\xc1\x84=\xc2\x84=\xc3\x84=\x12\x8b\x01\n\x0cListAccounts\x12\x30.meshtrade.wallet.account.v1.ListAccountsRequest\x1a\x31.meshtrade.wallet.account.v1.ListAccountsResponse\"\x16\xb2\xb5\x18\x12\x08\x01\x10\x02\x1a\x0c\xc0\x84=\xc1\x84=\xc2\x84=\xc3\x84=\x12\x91\x01\n\x0eSearchAccounts\x12\x32.meshtrade.wallet.account.v1.SearchAccountsRequest\x1a\x33.meshtrade.wallet.account.v1.SearchAccountsResponse\"\x16\xb2\xb5\x18\x12\x08\x01\x10\x02\x1a\x0c\xc0\x84=\xc1\x84=\xc2\x84=\xc3\x84=\x12\xa6\x01\n\x17RegisterTokensToAccount\x12;.meshtrade.wallet.account.v1.RegisterTokensToAccountRequest\x1a<.meshtrade.wallet.account.v1.RegisterTokensToAccountResponse\"\x10\xb2\xb5\x18\x0c\x08\x02\x10\x02\x1a\x06\xc0\x84=\xc2\x84=\x12\xb2\x01\n\x1b\x44\x65registerTokensFromAccount\x12?.meshtrade.wallet.account.v1.DeregisterTokensFromAccountRequest\x1a@.meshtrade.wallet.account.v1.DeregisterTokensFromAccountResponse\"\x10\xb2\xb5\x18\x0c\x08\x02\x10\x02\x1a\x06\xc0\x84=\xc2\x84=B^\n\"co.meshtrade.api.wallet.account.v1Z8github.com/meshtrade/api/go/wallet/account/v1;account_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.wallet.account.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"co.meshtrade.api.wallet.account.v1Z8github.com/meshtrade/api/go/wallet/account/v1;account_v1'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['account']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['account']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEACCOUNTREQUEST'].fields_by_name['account']._loaded_options = None
  _globals['_UPDATEACCOUNTREQUEST'].fields_by_name['account']._serialized_options = b'\272H\003\310\001\001'
  _globals['_OPENACCOUNTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_OPENACCOUNTREQUEST'].fields_by_name['name']._serialized_options = b'\272H8r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001#'
  _globals['_ADDSIGNATORIESTOACCOUNTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_ADDSIGNATORIESTOACCOUNTREQUEST'].fields_by_name['name']._serialized_options = b'\272H8r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001#'
  _globals['_ADDSIGNATORIESTOACCOUNTREQUEST'].fields_by_name['users']._loaded_options = None
  _globals['_ADDSIGNATORIESTOACCOUNTREQUEST'].fields_by_name['users']._serialized_options = b'\272H\226\002\222\001\222\002\010\001\020d\"\213\002r<2:^(users|api_users)/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\272\001\311\001\n\014users.format\0222each user must be api_users/{ULID} or users/{ULID}\032\204\001this.matches(\'^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\') || this.matches(\'^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')'
  _globals['_REMOVESIGNATORIESFROMACCOUNTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REMOVESIGNATORIESFROMACCOUNTREQUEST'].fields_by_name['name']._serialized_options = b'\272H8r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001#'
  _globals['_REMOVESIGNATORIESFROMACCOUNTREQUEST'].fields_by_name['users']._loaded_options = None
  _globals['_REMOVESIGNATORIESFROMACCOUNTREQUEST'].fields_by_name['users']._serialized_options = b'\272H\226\002\222\001\222\002\010\001\020d\"\213\002r<2:^(users|api_users)/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\272\001\311\001\n\014users.format\0222each user must be api_users/{ULID} or users/{ULID}\032\204\001this.matches(\'^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\') || this.matches(\'^api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')'
  _globals['_GETACCOUNTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETACCOUNTREQUEST'].fields_by_name['name']._serialized_options = b'\272H8r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001#'
  _globals['_GETACCOUNTBYNUMBERREQUEST'].fields_by_name['account_number']._loaded_options = None
  _globals['_GETACCOUNTBYNUMBERREQUEST'].fields_by_name['account_number']._serialized_options = b'\272H\017r\r2\013^1[0-9]{6}$'
  _globals['_LISTACCOUNTSREQUEST_SORTING'].fields_by_name['field']._loaded_options = None
  _globals['_LISTACCOUNTSREQUEST_SORTING'].fields_by_name['field']._serialized_options = b'\272H\\r\nR\000R\006number\272\001M\n\013field.valid\022&field must be one of: number, or empty\032\026this in [\'\', \'number\']'
  _globals['_SEARCHACCOUNTSREQUEST_SORTING'].fields_by_name['field']._loaded_options = None
  _globals['_SEARCHACCOUNTSREQUEST_SORTING'].fields_by_name['field']._serialized_options = b'\272H\\r\nR\000R\006number\272\001M\n\013field.valid\022&field must be one of: number, or empty\032\026this in [\'\', \'number\']'
  _globals['_SEARCHACCOUNTSREQUEST'].fields_by_name['display_name']._loaded_options = None
  _globals['_SEARCHACCOUNTSREQUEST'].fields_by_name['display_name']._serialized_options = b'\272Hmr\003\030\377\001\272\001e\n\027display_name.max_length\0227display_name search term must not exceed 255 characters\032\021size(this) <= 255'
  _globals['_REGISTERTOKENSTOACCOUNTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REGISTERTOKENSTOACCOUNTREQUEST'].fields_by_name['name']._serialized_options = b'\272H8r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001#'
  _globals['_REGISTERTOKENSTOACCOUNTREQUEST'].fields_by_name['tokens']._loaded_options = None
  _globals['_REGISTERTOKENSTOACCOUNTREQUEST'].fields_by_name['tokens']._serialized_options = b'\272H\007\222\001\004\010\001\020\n'
  _globals['_DEREGISTERTOKENSFROMACCOUNTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DEREGISTERTOKENSFROMACCOUNTREQUEST'].fields_by_name['name']._serialized_options = b'\272H8r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001#'
  _globals['_DEREGISTERTOKENSFROMACCOUNTREQUEST'].fields_by_name['tokens']._loaded_options = None
  _globals['_DEREGISTERTOKENSFROMACCOUNTREQUEST'].fields_by_name['tokens']._serialized_options = b'\272H\007\222\001\004\010\001\020\n'
  _globals['_ACCOUNTSERVICE'].methods_by_name['CreateAccount']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['CreateAccount']._serialized_options = b'\262\265\030\014\010\002\020\002\032\006\300\204=\302\204='
  _globals['_ACCOUNTSERVICE'].methods_by_name['UpdateAccount']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['UpdateAccount']._serialized_options = b'\262\265\030\014\010\002\020\002\032\006\300\204=\302\204='
  _globals['_ACCOUNTSERVICE'].methods_by_name['OpenAccount']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['OpenAccount']._serialized_options = b'\262\265\030\014\010\002\020\002\032\006\300\204=\302\204='
  _globals['_ACCOUNTSERVICE'].methods_by_name['AddSignatoriesToAccount']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['AddSignatoriesToAccount']._serialized_options = b'\262\265\030\014\010\002\020\002\032\006\300\204=\302\204='
  _globals['_ACCOUNTSERVICE'].methods_by_name['RemoveSignatoriesFromAccount']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['RemoveSignatoriesFromAccount']._serialized_options = b'\262\265\030\014\010\002\020\002\032\006\300\204=\302\204='
  _globals['_ACCOUNTSERVICE'].methods_by_name['GetAccount']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['GetAccount']._serialized_options = b'\262\265\030\022\010\001\020\002\032\014\300\204=\301\204=\302\204=\303\204='
  _globals['_ACCOUNTSERVICE'].methods_by_name['GetAccountByNumber']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['GetAccountByNumber']._serialized_options = b'\262\265\030\022\010\001\020\002\032\014\300\204=\301\204=\302\204=\303\204='
  _globals['_ACCOUNTSERVICE'].methods_by_name['ListAccounts']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['ListAccounts']._serialized_options = b'\262\265\030\022\010\001\020\002\032\014\300\204=\301\204=\302\204=\303\204='
  _globals['_ACCOUNTSERVICE'].methods_by_name['SearchAccounts']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['SearchAccounts']._serialized_options = b'\262\265\030\022\010\001\020\002\032\014\300\204=\301\204=\302\204=\303\204='
  _globals['_ACCOUNTSERVICE'].methods_by_name['RegisterTokensToAccount']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['RegisterTokensToAccount']._serialized_options = b'\262\265\030\014\010\002\020\002\032\006\300\204=\302\204='
  _globals['_ACCOUNTSERVICE'].methods_by_name['DeregisterTokensFromAccount']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['DeregisterTokensFromAccount']._serialized_options = b'\262\265\030\014\010\002\020\002\032\006\300\204=\302\204='
  _globals['_CREATEACCOUNTREQUEST']._serialized_start=267
  _globals['_CREATEACCOUNTREQUEST']._serialized_end=361
  _globals['_UPDATEACCOUNTREQUEST']._serialized_start=363
  _globals['_UPDATEACCOUNTREQUEST']._serialized_end=457
  _globals['_OPENACCOUNTREQUEST']._serialized_start=459
  _globals['_OPENACCOUNTREQUEST']._serialized_end=560
  _globals['_OPENACCOUNTRESPONSE']._serialized_start=562
  _globals['_OPENACCOUNTRESPONSE']._serialized_end=630
  _globals['_ADDSIGNATORIESTOACCOUNTREQUEST']._serialized_start=633
  _globals['_ADDSIGNATORIESTOACCOUNTREQUEST']._serialized_end=1054
  _globals['_ADDSIGNATORIESTOACCOUNTRESPONSE']._serialized_start=1056
  _globals['_ADDSIGNATORIESTOACCOUNTRESPONSE']._serialized_end=1136
  _globals['_REMOVESIGNATORIESFROMACCOUNTREQUEST']._serialized_start=1139
  _globals['_REMOVESIGNATORIESFROMACCOUNTREQUEST']._serialized_end=1565
  _globals['_REMOVESIGNATORIESFROMACCOUNTRESPONSE']._serialized_start=1567
  _globals['_REMOVESIGNATORIESFROMACCOUNTRESPONSE']._serialized_end=1652
  _globals['_GETACCOUNTREQUEST']._serialized_start=1655
  _globals['_GETACCOUNTREQUEST']._serialized_end=1805
  _globals['_GETACCOUNTBYNUMBERREQUEST']._serialized_start=1808
  _globals['_GETACCOUNTBYNUMBERREQUEST']._serialized_end=1944
  _globals['_LISTACCOUNTSREQUEST']._serialized_start=1947
  _globals['_LISTACCOUNTSREQUEST']._serialized_end=2288
  _globals['_LISTACCOUNTSREQUEST_SORTING']._serialized_start=2105
  _globals['_LISTACCOUNTSREQUEST_SORTING']._serialized_end=2288
  _globals['_LISTACCOUNTSRESPONSE']._serialized_start=2290
  _globals['_LISTACCOUNTSRESPONSE']._serialized_end=2378
  _globals['_SEARCHACCOUNTSREQUEST']._serialized_start=2381
  _globals['_SEARCHACCOUNTSREQUEST']._serialized_end=2876
  _globals['_SEARCHACCOUNTSREQUEST_SORTING']._serialized_start=2105
  _globals['_SEARCHACCOUNTSREQUEST_SORTING']._serialized_end=2288
  _globals['_SEARCHACCOUNTSRESPONSE']._serialized_start=2878
  _globals['_SEARCHACCOUNTSRESPONSE']._serialized_end=2968
  _globals['_REGISTERTOKENSTOACCOUNTREQUEST']._serialized_start=2971
  _globals['_REGISTERTOKENSTOACCOUNTREQUEST']._serialized_end=3146
  _globals['_REGISTERTOKENSTOACCOUNTRESPONSE']._serialized_start=3148
  _globals['_REGISTERTOKENSTOACCOUNTRESPONSE']._serialized_end=3228
  _globals['_DEREGISTERTOKENSFROMACCOUNTREQUEST']._serialized_start=3231
  _globals['_DEREGISTERTOKENSFROMACCOUNTREQUEST']._serialized_end=3410
  _globals['_DEREGISTERTOKENSFROMACCOUNTRESPONSE']._serialized_start=3412
  _globals['_DEREGISTERTOKENSFROMACCOUNTRESPONSE']._serialized_end=3496
  _globals['_ACCOUNTSERVICE']._serialized_start=3499
  _globals['_ACCOUNTSERVICE']._serialized_end=5154
# @@protoc_insertion_point(module_scope)
